@@ -6,12 +6,12 @@ use strict;
 use warnings;
 
 use Astro::Coord::ECI;
-use Astro::Coord::ECI::Utils qw{ AU deg2rad gm_strftime rad2deg };
+use Astro::Coord::ECI::Utils qw{ AU deg2rad rad2deg };
 use Carp;
 use Exporter qw{ import };
 use Test::More 0.88;	# Because of done_testing();
 
-our $VERSION = '0.006_02';
+our $VERSION = '0.001';
 
 our @EXPORT = qw{
     is_au_au
@@ -27,7 +27,7 @@ our @EXPORT = qw{
     use constant DEBUG => $ENV{VSOP87D_DEBUG};
 }
 
-sub is_au_au {
+sub is_au_au ($$$$) {
     my ( $got, $want, $dp, $title ) = @_;
     my $tplt = "%.${dp}f";
     @_ = (
@@ -38,12 +38,12 @@ sub is_au_au {
     goto &is;
 }
 
-sub is_km_au {
+sub is_km_au ($$$$) {
     splice @_, 0, 1, $_[0] / AU;
     goto &is_au_au;
 }
 
-sub is_rad_deg {
+sub is_rad_deg ($$$$) {
     my ( $got, $want, $dp, $title ) = @_;
     my $tplt = "%.${dp}f";
     @_ = (
@@ -56,12 +56,12 @@ sub is_rad_deg {
 
 sub strftime_h {
     my ( $time ) = @_;
-    return gm_strftime( '%Y-%m-%d %H', $time + 1800 );
+    return POSIX::strftime( '%Y-%m-%d %H', gmtime( $time + 1800 ) );
 }
 
 sub strftime_m {
     my ( $time ) = @_;
-    return gm_strftime( '%Y-%m-%d %H:%M', $time + 30 );
+    return POSIX::strftime( '%Y-%m-%d %H:%M', gmtime( $time + 30 ) );
 }
 
 sub washington_dc {
@@ -207,9 +207,7 @@ L<Astro::Coord::ECI::VSOP87D|Astro::Coord::ECI::VSOP87D>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-VSOP87D>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI-VSOP87D/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -217,7 +215,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2022, 2024 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
