@@ -5,8 +5,6 @@ use 5.008;
 use strict;
 use warnings;
 
-use utf8;
-
 use Astro::Coord::ECI::Utils qw{
     AU PI SECSPERDAY TWOPI
     asin deg2rad jcent2000 julianday
@@ -28,7 +26,7 @@ BEGIN {
 	or constant->import( DEBUG => 0 );
 }
 
-our $VERSION = '0.006_02';
+our $VERSION = '0.001';
 
 my @basic_export = qw{
     SUN_CLASS
@@ -221,6 +219,7 @@ EOD
 	rad2dms( $delta_lambda), rad2deg( $lambda ), rad2dms( $lambda ),
 	rad2dms( $delta_beta), rad2deg( $beta ), rad2dms( $beta );
 
+
     } else {			# The Sun
 	( $lambda, $beta, $Delta ) = ( mod2pi( $Le + PI ), - $Be, $Re );
 	$long_sym = '☉';
@@ -249,6 +248,7 @@ EOD
 	$long_sym, rad2deg( $lambda ),
 	rad2deg( $beta ), rad2dms( $beta ), $Delta;
 
+
     # Convert to FK5. Meeus says (ch. 25 pg 166) this is necessary for
     # high accuracy (though not if using his truncated VSOP87D), though
     # Bretagnon & Francou seem to say it is needed only for VSOP87 and
@@ -904,7 +904,7 @@ __END__
 
 =head1 NAME
 
-Astro::Coord::ECI::VSOP87D - Implement the VSOP87D planetary position model.
+Astro::Coord::ECI::VSOP87D - Implement the VSOP87D position model.
 
 =head1 SYNOPSIS
 
@@ -1122,7 +1122,7 @@ The C<$cutoff> argument is optional; if specified as a number larger
 than C<0>, terms whose amplitudes are smaller than the nutation cutoff
 (in milli arc seconds) are ignored. The Meeus version of the algorithm
 is specified by a value of C<3>. The default is specified by the
-C<nutation_cutoff> attribute.
+L<nutation_cutoff|/nutation_cutoff> attribute.
 
 The model itself is the IAU 1980 nutation model. Later models exist, but
 this was chosen because of the desire to be compatible with Meeus'
@@ -1357,9 +1357,7 @@ for daily events involving astronomical bodies.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-VSOP87D>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI-VSOP87D/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -1367,7 +1365,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2022, 2024 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
