@@ -15,7 +15,7 @@ use Astro::Coord::ECI::Utils qw{ PI PIOVER2 find_first_true mod2pi };
 use Astro::Coord::ECI::VSOP87D qw{ :mixin };
 use Carp;
 
-our $VERSION = '0.006_02';
+our $VERSION = '0.001';
 
 sub new {
     my ( $class, %arg ) = @_;
@@ -390,9 +390,7 @@ L<Astro::Coord::ECI::VSOP87D|Astro::Coord::ECI::VSOP87D>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-Coord-ECI-VSOP87D>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI-VSOP87D/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -400,7 +398,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2022, 2024 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
